require(ecodist)

### Pathogen versus Geo genetic distances

Pathogen <- read.csv("coxiella.csv")
PathogenMat <- as.matrix(Pathogen[1:37, 2:38])
PathogenDist <- PathogenMat[lower.tri(PathogenMat)]

Geo <- read.csv("geo.csv")
GeoMat <- as.matrix(Geo[1:37, 2:38])
GeoDist <- GeoMat[lower.tri(GeoMat)]

GeoMantel.Lin <- mantel(PathogenDist ~ GeoDist, mrank = FALSE, nperm=10000)
GeoMantel.Lin

plot(GeoDist, PathogenDist, pch=19, col=2, xlab= "Geo distance", ylab= "Pathogen Distance", main="Association of pathogen and geo distances")
abline(lm(PathogenDist ~ GeoDist), lwd=2, col="navy")

bump.pmgram <- pmgram(PathogenDist, GeoDist, nperm = 10000, nclass = 10)
bump.pmgram
plot(bump.pmgram, pval = 0.01)

### Pathogen genetic distance versus Host distance

Host <- read.csv("host.csv")
HostMat <- as.matrix(Host[1:37, 2:38])
HostDist <- HostMat[lower.tri(HostMat)]

HostMantel.Lin <- mantel(PathogenDist ~ HostDist, nperm=10000)
HostMantel.Lin

plot(HostDist, PathogenDist, pch=19, col=2, xlab= "Host distance", ylab= "Pathogen Distance", main="Association of pathogen and host distances")
abline(lm(PathogenDist ~HostDist), lwd=2, col="navy")

bump.pmgram <- pmgram(PathogenDist, HostDist, nperm = 10000, nclass = 10)
bump.pmgram
plot(bump.pmgram, pval = 0.01)


### Partial pathogen versus geo, exclude the effect of host

GeoMantelPartial.Lin <- mantel(PathogenDist ~ GeoDist + HostDist, mrank = FALSE, nperm=10000)
GeoMantelPartial.Lin

cov.pmgram <- pmgram(PathogenDist, GeoDist, HostDist, nclass = 20, nperm = 1000)
plot(cov.pmgram)

### Partial pathogen versus host, exclude the effect of geo

GeoMantelPartial.Lin <- mantel(PathogenDist ~ HostDist + GeoDist, mrank = FALSE, nperm=10000)
GeoMantelPartial.Lin

cov.pmgram <- pmgram(PathogenDist, HostDist, GeoDist, nclass = 20, nperm = 1000)
plot(cov.pmgram)


### Multiple regression on distance matrix

cov.mrm <- MRM(PathogenDist ~ GeoDist + HostDist, nperm=10000)
cov.mrm

